namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type Spin::min_max_get( ::efl::eolian::out_traits<double>::type min,  ::efl::eolian::out_traits<double>::type max) const
{
   double __out_param_min = {};
   double __out_param_max = {};
    ::efl_ui_spin_min_max_get(this->_eo_ptr()
      , & __out_param_min
      , & __out_param_max);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(min, __out_param_min);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(max, __out_param_max);
}
inline ::efl::eolian::return_traits<void>::type Spin::min_max_set( ::efl::eolian::in_traits<double>::type min,  ::efl::eolian::in_traits<double>::type max) const
{
    ::efl_ui_spin_min_max_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(min)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(max));
}
inline ::efl::eolian::return_traits<double>::type Spin::step_get() const
{
   double __return_value =  ::efl_ui_spin_step_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::step_set( ::efl::eolian::in_traits<double>::type step) const
{
    ::efl_ui_spin_step_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(step));
}
inline ::efl::eolian::return_traits<double>::type Spin::value_get() const
{
   double __return_value =  ::efl_ui_spin_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::value_set( ::efl::eolian::in_traits<double>::type val) const
{
    ::efl_ui_spin_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits<double>::type Spin::interval_get() const
{
   double __return_value =  ::efl_ui_spin_interval_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::interval_set( ::efl::eolian::in_traits<double>::type interval) const
{
    ::efl_ui_spin_interval_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(interval));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type Spin::min_max_get( ::efl::eolian::out_traits<double>::type min,  ::efl::eolian::out_traits<double>::type max) const
{
   double __out_param_min = {};
   double __out_param_max = {};
    ::efl_ui_spin_min_max_get(this->_eo_ptr()
      , & __out_param_min
      , & __out_param_max);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(min, __out_param_min);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(max, __out_param_max);
}
inline ::efl::eolian::return_traits<void>::type Spin::min_max_set( ::efl::eolian::in_traits<double>::type min,  ::efl::eolian::in_traits<double>::type max) const
{
    ::efl_ui_spin_min_max_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(min)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(max));
}
inline ::efl::eolian::return_traits<double>::type Spin::step_get() const
{
   double __return_value =  ::efl_ui_spin_step_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::step_set( ::efl::eolian::in_traits<double>::type step) const
{
    ::efl_ui_spin_step_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(step));
}
inline ::efl::eolian::return_traits<double>::type Spin::value_get() const
{
   double __return_value =  ::efl_ui_spin_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::value_set( ::efl::eolian::in_traits<double>::type val) const
{
    ::efl_ui_spin_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits<double>::type Spin::interval_get() const
{
   double __return_value =  ::efl_ui_spin_interval_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Spin::interval_set( ::efl::eolian::in_traits<double>::type interval) const
{
    ::efl_ui_spin_interval_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(interval));
}
inline efl::ui::Spin::operator ::efl::ui::Spin() const { return *static_cast< ::efl::ui::Spin const*>(static_cast<void const*>(this)); }
inline efl::ui::Spin::operator ::efl::ui::Spin&() { return *static_cast< ::efl::ui::Spin*>(static_cast<void*>(this)); }
inline efl::ui::Spin::operator ::efl::ui::Spin const&() const { return *static_cast< ::efl::ui::Spin const*>(static_cast<void const*>(this)); }
} } }

